==> styletron-react-2.1.2.tgz: package/lib/styled.js <==
var React = require('react');
var utils = require('styletron-utils');

var isValidAttr = require('./is-valid-attr');

var STYLES_KEY = '__STYLETRON_STYLES';
var TAG_KEY = '__STYLETRON_TAG';

module.exports = styled;

/**
 * Helper function to create styled element components
 * @packagename styletron-react
 * @param  {String|function} base     Tag name or styled element component
 * @param  {function|object} styleFn  Style object or function that returns a style object
 * @return {function}                 Styled element component
 * @example
 * import {styled} from 'styletron-react';
 *
 * const Panel = styled('div', {
 *   backgroundColor: 'lightblue',
 *   fontSize: '12px'
 * });
 *
 * <Panel>Hello World</Panel>
 * @example
 * import {styled} from 'styletron-react';
 *
 * const Panel = styled('div', (props) => ({
 *   backgroundColor: props.alert ? 'orange' : 'lightblue',
 *   fontSize: '12px'
 * }));
 *
 * <Panel alert>Danger!</Panel>
 * @example
 * import {styled} from 'styletron-react';
 *
 * const DeluxePanel = styled(Panel, (props) => ({
 *   backgroundColor: props.alert ? 'firebrick' : 'rebeccapurple',
 *   color: 'white',
 *   boxShadow: '3px 3px 3px darkgray'
 * }));
 *
 * <DeluxePanel>Bonjour Monde</DeluxePanel>
 */
function styled(base, styleArg) {
  if (typeof base === 'string') {
    // Element
    return createStyledElementComponent(
      base,
      [styleArg]
    );
  }
  if (typeof base === 'function' && base[TAG_KEY] && base[STYLES_KEY]) {
    // Component
    return createStyledElementComponent(
      base[TAG_KEY],
      base[STYLES_KEY].concat(styleArg)
    );
  }
  throw Error('Must pass in element or component');
}

function createStyledElementComponent(tagName, stylesArray) {

  var StyledElement = function (props, context) {
    
    var resolvedStyle = {};
    StyledElement[STYLES_KEY].forEach(function (style) {
      if (typeof style === 'function') {
        assign(resolvedStyle, style(props, context));
      } else if (typeof style === 'object') {
        assign(resolvedStyle, style);
      }
    });

    var styletronClassName = utils.injectStylePrefixed(context.styletron, resolvedStyle);

    var elementProps = omitInvalidProps(props);
    elementProps.className = props.className
      ? ((props.className) + " " + styletronClassName)
      : styletronClassName;

    return React.createElement(StyledElement[TAG_KEY], elementProps);
  };

  StyledElement[TAG_KEY] = tagName;
  StyledElement[STYLES_KEY] = stylesArray;
  StyledElement.contextTypes = {styletron: React.PropTypes.object};

  return StyledElement;
}

function assign(target, source) {
  for (var key in source) {
    target[key] = source[key];
  }
}

function omitInvalidProps(props) {
  var target = {};
  for (var attr in props) {
    if (isValidAttr(attr)) {
      target[attr] = props[attr];
    }
  }
  return target;
}

==> styletron-react-2.2.0.tgz: package/lib/styled.js <==
var React = require('react');
var utils = require('styletron-utils');

var isValidAttr = require('./is-valid-attr');

var STYLES_KEY = '__STYLETRON_STYLES';
var TAG_KEY = '__STYLETRON_TAG';

module.exports = styled;

/**
 * Helper function to create styled element components
 * @packagename styletron-react
 * @param  {String|function} base     Tag name or styled element component
 * @param  {function|object} styleFn  Style object or function that returns a style object
 * @return {function}                 Styled element component
 * @example
 * import {styled} from 'styletron-react';
 *
 * const Panel = styled('div', {
 *   backgroundColor: 'lightblue',
 *   fontSize: '12px'
 * });
 *
 * <Panel>Hello World</Panel>
 * @example
 * import {styled} from 'styletron-react';
 *
 * const Panel = styled('div', (props) => ({
 *   backgroundColor: props.alert ? 'orange' : 'lightblue',
 *   fontSize: '12px'
 * }));
 *
 * <Panel alert>Danger!</Panel>
 * @example
 * import {styled} from 'styletron-react';
 *
 * const DeluxePanel = styled(Panel, (props) => ({
 *   backgroundColor: props.alert ? 'firebrick' : 'rebeccapurple',
 *   color: 'white',
 *   boxShadow: '3px 3px 3px darkgray'
 * }));
 *
 * <DeluxePanel>Bonjour Monde</DeluxePanel>
 */
function styled(base, styleArg) {
  if (typeof base === 'string') {
    // Element
    return createStyledElementComponent(
      base,
      [styleArg]
    );
  }
  if (typeof base === 'function' && base[TAG_KEY] && base[STYLES_KEY]) {
    // Component
    return createStyledElementComponent(
      base[TAG_KEY],
      base[STYLES_KEY].concat(styleArg)
    );
  }
  throw Error('Must pass in element or component');
}

function createStyledElementComponent(tagName, stylesArray) {

  var StyledElement = (function (superclass) {
    function StyledElement () {
      superclass.apply(this, arguments);
    }

    if ( superclass ) StyledElement.__proto__ = superclass;
    StyledElement.prototype = Object.create( superclass && superclass.prototype );
    StyledElement.prototype.constructor = StyledElement;

    StyledElement.prototype.render = function render () {
      var this$1 = this;

      var resolvedStyle = {};
      StyledElement[STYLES_KEY].forEach(function (style) {
        if (typeof style === 'function') {
          assign(resolvedStyle, style(this$1.props, this$1.context));
        } else if (typeof style === 'object') {
          assign(resolvedStyle, style);
        }
      });

      var styletronClassName = utils.injectStylePrefixed(this.context.styletron, resolvedStyle);

      var elementProps = omitInvalidProps(this.props);
      elementProps.className = this.props.className
        ? ((this.props.className) + " " + styletronClassName)
        : styletronClassName;

      if (this.props.innerRef) {
        elementProps.ref = this.props.innerRef;
      }

      return React.createElement(StyledElement[TAG_KEY], elementProps);
    };

    return StyledElement;
  }(React.Component));

  StyledElement[TAG_KEY] = tagName;
  StyledElement[STYLES_KEY] = stylesArray;
  StyledElement.contextTypes = {styletron: React.PropTypes.object};

  return StyledElement;
}

function assign(target, source) {
  for (var key in source) {
    target[key] = source[key];
  }
}

function omitInvalidProps(props) {
  var target = {};
  for (var attr in props) {
    if (isValidAttr(attr)) {
      target[attr] = props[attr];
    }
  }
  return target;
}
